# ACROSS API Python Client

This is the Python API for the Astrophysics Cross-Observatory Science Support (ACROSS), a NASA initiative to provide cross-observatory support for time-domain and multi-messenger (TDAMM) coordination and observation planning.

To install the `across_client` Python module, please do the following:

1. Clone the repository to your computer.
2. Enter the directory and install the module using `pip install .`

The `across_client` module should now be available for use.
